@@ -21,7 +21,6 @@
 #include <Python.h>
 #include <glib.h>
 
-#include "pygi-python-compat.h"
 #include "pygi-array.h"
 #include "pygi-info.h"
 #include "pygi-marshal-cleanup.h"
@@ -251,8 +250,8 @@ _pygi_marshal_from_py_array (PyGIInvokeState   *state,
     }
 
     if (sequence_cache->item_cache->type_tag == GI_TYPE_TAG_UINT8 &&
-        PYGLIB_PyBytes_Check (py_arg)) {
-        gchar *data = PYGLIB_PyBytes_AsString (py_arg);
+        PyBytes_Check (py_arg)) {
+        gchar *data = PyBytes_AsString (py_arg);
 
         /* Avoid making a copy if the data
          * is not transferred to the C function
@@ -546,10 +545,16 @@ _pygi_marshal_to_py_array (PyGIInvokeState   *state,
         } else if (array_cache->is_zero_terminated) {
             if (arg->v_pointer == NULL) {
                 len = 0;
-            } else if (seq_cache->item_cache->type_tag == GI_TYPE_TAG_UINT8) {
+            } else if (array_cache->item_size == 1) {
                 len = strlen (arg->v_pointer);
-            } else {
+            } else if (array_cache->item_size == sizeof(gpointer)) {
                 len = g_strv_length ((gchar **)arg->v_pointer);
+            } else if (array_cache->item_size == sizeof(int)) {
+                for (len = 0; *(((int*)arg->v_pointer) + len); len++);
+            } else if (array_cache->item_size == sizeof(short)) {
+                for (len = 0; *(((short*)arg->v_pointer) + len); len++);
+            } else {
+                g_assert_not_reached ();
             }
         } else {
             GIArgument *len_arg = &state->args[array_cache->len_arg_index].arg_value;
@@ -583,9 +588,9 @@ _pygi_marshal_to_py_array (PyGIInvokeState   *state,
 
     if (seq_cache->item_cache->type_tag == GI_TYPE_TAG_UINT8) {
         if (arg->v_pointer == NULL) {
-            py_obj = PYGLIB_PyBytes_FromString ("");
+            py_obj = PyBytes_FromString ("");
         } else {
-            py_obj = PYGLIB_PyBytes_FromStringAndSize (array_->data, array_->len);
+            py_obj = PyBytes_FromStringAndSize (array_->data, array_->len);
         }
     } else {
         if (arg->v_pointer == NULL) {
@@ -718,7 +723,16 @@ _wrap_c_array (PyGIInvokeState   *state,
     if (array_cache->fixed_size >= 0) {
         len = array_cache->fixed_size;
     } else if (array_cache->is_zero_terminated) {
-        len = g_strv_length ((gchar **)data);
+        if (array_cache->item_size == sizeof(gpointer))
+            len = g_strv_length ((gchar **)data);
+        else if (array_cache->item_size == 1)
+            len = strlen ((gchar*)data);
+        else if (array_cache->item_size == sizeof(int))
+            for (len = 0; *(((int*)data) + len); len++);
+        else if (array_cache->item_size == sizeof(short))
+            for (len = 0; *(((short*)data) + len); len++);
+        else
+            g_assert_not_reached ();
     } else if (array_cache->len_arg_index >= 0) {
         GIArgument *len_arg = &state->args[array_cache->len_arg_index].arg_value;
         len = len_arg->v_long;
